Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/ConnectorServlet.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/ConnectorServlet.java	(revision 2027)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/ConnectorServlet.java	(revision 2028)
@@ -124,8 +124,5 @@
 			ResourceTypeHandler resourceType = ResourceTypeHandler.getDefaultResourceType(typeStr);
 
-			// TODO this is not good for accessing server-side resources
-			// suitable only for XmlResponse
-			String typePath = UtilsResponse.constructResponseUrl(request, resourceType,
-			        null, false, false);
+			String typePath = UtilsFile.constructServerSidePath(request, resourceType);
 			String typeDirPath = getServletContext().getRealPath(typePath);
 
@@ -212,10 +209,10 @@
 
 		if (!RequestCycleHandler.isEnabledForFileUpload(request))
-			ur = new UploadResponse(UploadResponse.EN_SECURITY_ERROR, null, null,
+			ur = new UploadResponse(UploadResponse.SC_SECURITY_ERROR, null, null,
 			        Messages.NOT_AUTHORIZED_FOR_UPLOAD);
 		else if (!CommandHandler.isValidForPost(commandStr))
-			ur = new UploadResponse(UploadResponse.EN_ERROR, null, null, Messages.INVALID_COMMAND);
+			ur = new UploadResponse(UploadResponse.SC_ERROR, null, null, Messages.INVALID_COMMAND);
 		else if (typeStr != null && !ResourceTypeHandler.isValid(typeStr))
-			ur = new UploadResponse(UploadResponse.EN_ERROR, null, null, Messages.INVALID_TYPE);
+			ur = new UploadResponse(UploadResponse.SC_ERROR, null, null, Messages.INVALID_TYPE);
 		else if (!UtilsFile.isValidPath(currentFolderStr))
 			ur = UploadResponse.UR_INVALID_CURRENT_FOLDER;
@@ -223,8 +220,5 @@
 			ResourceTypeHandler resourceType = ResourceTypeHandler.getDefaultResourceType(typeStr);
 
-			// FIXME this is not good for accessing server-side resources
-			// suitable only for XmlResponse
-			String typePath = UtilsResponse.constructResponseUrl(request, resourceType,
-			        null, false, false);
+			String typePath = UtilsFile.constructServerSidePath(request, resourceType);
 			String typeDirPath = getServletContext().getRealPath(typePath);
 
@@ -254,5 +248,5 @@
 
 					if (!ExtensionsHandler.isAllowed(resourceType, extension))
-						ur = new UploadResponse(UploadResponse.EN_INVALID_EXTENSION);
+						ur = new UploadResponse(UploadResponse.SC_INVALID_EXTENSION);
 					else {
 
@@ -268,9 +262,9 @@
 
 						if (Utils.isEmpty(newFilename))
-							ur = new UploadResponse(UploadResponse.EN_OK, UtilsResponse
+							ur = new UploadResponse(UploadResponse.SC_OK, UtilsResponse
 							        .constructResponseUrl(request, resourceType, currentFolderStr,
 							                true, ConnectorHandler.isFullUrl()).concat(filename));
 						else
-							ur = new UploadResponse(UploadResponse.EN_RENAMED,
+							ur = new UploadResponse(UploadResponse.SC_RENAMED,
 							        UtilsResponse.constructResponseUrl(request, resourceType,
 							                currentFolderStr, true, ConnectorHandler.isFullUrl())
@@ -284,5 +278,5 @@
 							else {
 								uplFile.delete();
-								ur = new UploadResponse(UploadResponse.EN_INVALID_EXTENSION);
+								ur = new UploadResponse(UploadResponse.SC_INVALID_EXTENSION);
 							}
 						} else
@@ -291,5 +285,5 @@
 					}
 				} catch (Exception e) {
-					ur = new UploadResponse(UploadResponse.EN_SECURITY_ERROR);
+					ur = new UploadResponse(UploadResponse.SC_SECURITY_ERROR);
 				}
 			}
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java	(revision 2027)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsFile.java	(revision 2028)
@@ -24,4 +24,6 @@
 import java.io.InputStream;
 
+import javax.servlet.http.HttpServletRequest;
+
 import org.apache.commons.io.FilenameUtils;
 import org.devlib.schmidt.imageinfo.ImageInfo;
@@ -30,4 +32,5 @@
 
 import net.fckeditor.handlers.ConnectorHandler;
+import net.fckeditor.handlers.ResourceTypeHandler;
 
 /**
@@ -141,4 +144,19 @@
 		}
 	}
+	
+	/**
+	 * TODO - document me!
+	 * @param request
+	 * @param resourceType
+	 * @return
+	 */
+	public static String constructServerSidePath(HttpServletRequest request,
+			ResourceTypeHandler resourceType) {
+		StringBuffer sb = new StringBuffer(ConnectorHandler
+				.getUserFilesPath(request));
+		sb.append(resourceType.getPath());
+
+		return sb.toString();
+	}
 
 }
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java	(revision 2027)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tool/UtilsResponse.java	(revision 2028)
@@ -38,5 +38,5 @@
      * @param request
      * @param resourceType
-     * @param urlPath TODO
+     * @param urlPath
      * @param prependContextPath
      * @param fullUrl
@@ -67,19 +67,3 @@
     }
 
-	/**
-	 * TODO - document me!
-	 * 
-	 * @param request
-	 * @param resourceType
-	 * @param prependContextPath
-	 * @param fullUrl
-	 * @return constructed url
-	 */
-	public static String constructResponseUrl(HttpServletRequest request,
-    		ResourceTypeHandler resourceType, boolean prependContextPath, 
-    		boolean fullUrl) {
-    	return constructResponseUrl(request, resourceType, null, 
-    			prependContextPath, fullUrl);
-    }
-
 }

Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java	(revision 2027)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java	(revision 2028)
@@ -39,5 +39,5 @@
  * The UploadResponse constructor behaves the same way by simply calling it
  * with:<br/>
- * <code>UploadResponse ur = new UploadResonse(EN_SOME_ERROR,"/some/url/file.img","file.img","no error"):</code>
+ * <code>UploadResponse ur = new UploadResonse(SC_SOME_ERROR,"/some/url/file.img","file.img","no error"):</code>
  * </p>
  * 
@@ -49,23 +49,23 @@
 	private Object[] parameters;
 
-	// TODO Rename 'En_'-constants to something more intuitive like 'CODE_'
+	// Naming scheme according static status codes in javax.servlet.http.HttpServletResponse
 	/** Error number OK */
-	public static final int EN_OK = 0;
+	public static final int SC_OK = 0;
 
 	/** Error number ERROR */
-	public static final int EN_ERROR = 1;
+	public static final int SC_ERROR = 1;
 
 	/** Error number RENAMED */
-	public static final int EN_RENAMED = 201;
+	public static final int SC_RENAMED = 201;
 
 	/** Error number INVALID EXTENSION */
-	public static final int EN_INVALID_EXTENSION = 202;
+	public static final int SC_INVALID_EXTENSION = 202;
 
 	/** Error number SECURITY ERROR */
-	public static final int EN_SECURITY_ERROR = 203;
+	public static final int SC_SECURITY_ERROR = 203;
 	
 	/** UploadResponse INVALID CURRENT FOLDER */
 	public static final UploadResponse UR_INVALID_CURRENT_FOLDER = new UploadResponse(
-			UploadResponse.EN_ERROR, null, null,
+			UploadResponse.SC_ERROR, null, null,
 			Messages.INVALID_CURRENT_FOLDER);
 
@@ -75,7 +75,7 @@
 	 * Put the desired parameters in the constructor. You may omit them from
 	 * right to left but you have to remain the order.<br/> e.g.
 	 * <code>UploadResponse(EN_OK,"/some/url/to/pic.jpg","pic")</code> or
 	 * <code>UploadResponse(EN_OK)</code> but <b>not</b>
 	 * <code>UploadResponse(EN_OK,"some error message")</code>
 	 * </p>
 	 * <p>
@@ -75,7 +75,7 @@
 	 * Put the desired parameters in the constructor. You may omit them from
 	 * right to left but you have to remain the order.<br/> e.g.
-	 * <code>UploadResponse(EN_OK,"/some/url/to/pic.jpg","pic")</code> or
-	 * <code>UploadResponse(EN_OK)</code> but <b>not</b>
-	 * <code>UploadResponse(EN_OK,"some error message")</code>
+	 * <code>UploadResponse(SC_OK,"/some/url/to/pic.jpg","pic")</code> or
+	 * <code>UploadResponse(SC_OK)</code> but <b>not</b>
+	 * <code>UploadResponse(SC_OK,"some error message")</code>
 	 * </p>
 	 * <p>